@@ -17,6 +17,7 @@ class UUIDType(TypeDecorator):
     CHAR(32), storing as stringified hex values.
 
     """
+
     impl = CHAR
     cache_ok = True
 
@@ -25,7 +26,7 @@ class UUIDType(TypeDecorator):
         return uuid.UUID
 
     def load_dialect_impl(self, dialect):
-        if dialect.name == 'postgresql':
+        if dialect.name == "postgresql":
             return dialect.type_descriptor(UUID())
         else:
             return dialect.type_descriptor(CHAR(32))
@@ -33,7 +34,7 @@ class UUIDType(TypeDecorator):
     def process_bind_param(self, value, dialect):
         if value is None:
             return value
-        elif dialect.name == 'postgresql':
+        elif dialect.name == "postgresql":
             return str(value)
         else:
             if not isinstance(value, uuid.UUID):
@@ -52,9 +53,9 @@ class UUIDType(TypeDecorator):
 
 
 class EnumType(TypeFactory):
-
     def to_type(self, python_type: Type) -> Optional[Type[TypeEngine]]:
         if issubclass(python_type, enum.Enum):
+
             class Enum(SQLAlchemyEnum):
                 _python_type = python_type
 
