@@ -1,12 +1,27 @@
+from datetime import datetime, date, time, timedelta
+from decimal import Decimal
 from typing import Type, Optional, List
+from uuid import UUID
 
+from sqlalchemy import (
+    String,
+    Date,
+    DateTime,
+    Time,
+    Integer,
+    Numeric,
+    Float,
+    LargeBinary,
+    Boolean,
+    JSON,
+    Uuid,
+)
 from sqlalchemy.sql.type_api import TypeEngine
 
 from sqlalchemy_orm.utils import get_all_subclasses
 
 
 class TypeFactory:
-
     def __init__(self, type_map=None):
         pass
 
@@ -15,7 +30,6 @@ class TypeFactory:
 
 
 class TypeMapper:
-
     def __init__(self, type_map=None, types=None):
         if not types:
             types = []
@@ -23,10 +37,26 @@ class TypeMapper:
         if not type_map:
             type_map = {}
 
-        self.type_map = {}
+        self.type_map = {
+            str: String(),
+            datetime: DateTime(),
+            date: Date(),
+            time: Time(),
+            timedelta: DateTime(),
+            int: Integer(),
+            Decimal: Numeric(),
+            float: Float(),
+            bytes: LargeBinary(),
+            bool: Boolean(),
+            dict: JSON(),
+            UUID: Uuid(),
+            **type_map,
+        }
         self.type_factories: List[TypeFactory] = []
+        _types = types + get_all_subclasses(TypeEngine)
 
-        for type_ in types + get_all_subclasses(TypeEngine):
+        for type_ in _types:
+            origin = type_
             if issubclass(type_, TypeFactory):
                 self.type_factories.append(type_(type_map=self))
                 continue
@@ -37,7 +67,7 @@ class TypeMapper:
                 else:
                     type_obj = type_
 
-                if not hasattr(type_obj, '__visit_name__'):
+                if not hasattr(type_obj, "__visit_name__"):
                     continue
 
                 python_type = type_obj.python_type
@@ -50,9 +80,10 @@ class TypeMapper:
             except Exception:
                 pass
             else:
-                type_map = self.type_map
-                if python_type not in type_map.keys() or \
-                        issubclass(type_map[python_type].__class__, type_):
+                if python_type not in self.type_map.keys() or issubclass(
+                    self.type_map[python_type].__class__, type_
+                ):
+                    type_obj.origin = origin
                     self.type_map[python_type] = type_obj
                 elif type_obj in self.type_map.values():
                     raise TypeError(
